Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9)

Unified Diff: syzygy/experimental/protect/protect_lib/protect_app.h

Issue 2535563002: Added all code for integrity check transform (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: syzygy/experimental/protect/protect_lib/protect_app.h
diff --git a/syzygy/poirot/poirot_app.h b/syzygy/experimental/protect/protect_lib/protect_app.h
similarity index 54%
copy from syzygy/poirot/poirot_app.h
copy to syzygy/experimental/protect/protect_lib/protect_app.h
index fd807fdeff493b9b522fac98f37b415157ead0f4..cbfcb2bf638178d3d6275137b635a64db586dafb 100644
--- a/syzygy/poirot/poirot_app.h
+++ b/syzygy/experimental/protect/protect_lib/protect_app.h
@@ -1,60 +1,51 @@
-// Copyright 2015 Google Inc. All Rights Reserved.
-//
-// Licensed under the Apache License, Version 2.0 (the "License");
-// you may not use this file except in compliance with the License.
-// You may obtain a copy of the License at
-//
-// http://www.apache.org/licenses/LICENSE-2.0
-//
-// Unless required by applicable law or agreed to in writing, software
-// distributed under the License is distributed on an "AS IS" BASIS,
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-// See the License for the specific language governing permissions and
-// limitations under the License.
-
-#ifndef SYZYGY_POIROT_POIROT_APP_H_
-#define SYZYGY_POIROT_POIROT_APP_H_
-
-#include "base/command_line.h"
-#include "base/files/file_path.h"
-#include "base/strings/string_piece.h"
-#include "syzygy/application/application.h"
-#include "syzygy/poirot/minidump_processor.h"
-
-namespace poirot {
-
-// This class implements the minidump processor command-line utility.
-//
-// See the description given in PoirotApp:::PrintUsage() for
-// information about running this utility.
-class PoirotApp : public application::AppImplBase {
- public:
- // @name Implementation of the AppImplBase interface.
- // @{
- PoirotApp() : application::AppImplBase("PoirotApp") {}
-
- bool ParseCommandLine(const base::CommandLine* command_line);
-
- int Run();
- // @}
-
- protected:
- // @name Utility function
- // @{
- void PrintUsage(const base::FilePath& program,
- const base::StringPiece& message);
- // @}
-
- // @name Command-line options.
- // @{
- base::FilePath input_minidump_;
- base::FilePath output_file_;
- // @}
-
- private:
- DISALLOW_COPY_AND_ASSIGN(PoirotApp);
-};
-
-} // namespace poirot
-
-#endif // SYZYGY_POIROT_POIROT_APP_H_
+// Copyright 2015 Google Inc. All Rights Reserved.
+//
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+//
+// http://www.apache.org/licenses/LICENSE-2.0
+//
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+
+#ifndef SYZYGY_PROTECT_PROTECT_LIB_PROTECT_APP_H_
+#define SYZYGY_PROTECT_PROTECT_LIB_PROTECT_APP_H_
+
+#include "base/command_line.h"
+#include "base/files/file_path.h"
+#include "base/strings/string_piece.h"
+#include "base/time/time.h"
+#include "base/values.h"
+#include "syzygy/application/application.h"
+#include "syzygy/block_graph/block_graph.h"
+#include "syzygy/experimental/protect/protect_lib/protect_flummox.h"
+
+namespace protect {
+
+// This class implements the command-line Protect utility.
+class ProtectApp : public application::AppImplBase {
+public:
+ ProtectApp() : AppImplBase("ProtectApp") {}
+
+ // @name Implementation of the AppImplBase interface.
+ // @{
+ bool ParseCommandLine(const base::CommandLine* command_line);
+ bool SetUp();
+ int Run();
+ // @}
+
+ protected:
+ bool overwrite_;
+ scoped_ptr<CustomFlummoxInstrumenter> instrumenter_;
+
+ private:
+ DISALLOW_COPY_AND_ASSIGN(ProtectApp);
+};
+
+} // namespace protect
+
+#endif // SYZYGY_PROTECT_PROTECT_LIB_PROTECT_APP_H_

Powered by Google App Engine
This is Rietveld 408576698